package com.ruoyi.system.service.impl.project;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.project.BmDeptPlanArea;
import com.ruoyi.system.domain.vo.BmDeptPlanVo;
import com.ruoyi.system.mapper.project.BmDeptPlanAreaMapper;
import com.ruoyi.system.service.project.IBmDeptPlanAreaService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * 两区及乡镇单位部门招商计划Service业务层处理
 * 
 * @author ruoyi
 * @date 2021-07-05
 */
@Service
public class BmDeptPlanAreaServiceImpl implements IBmDeptPlanAreaService
{
    @Autowired
    private BmDeptPlanAreaMapper bmDeptPlanAreaMapper;

    /**
     * 查询两区及乡镇单位部门招商计划
     * 
     * @param id 两区及乡镇单位部门招商计划ID
     * @return 两区及乡镇单位部门招商计划
     */
    @Override
    public BmDeptPlanArea selectBmDeptPlanAreaById(Long id)
    {
        return bmDeptPlanAreaMapper.selectBmDeptPlanAreaById(id);
    }

    /**
     * 查询两区及乡镇单位部门招商计划列表
     * 
     * @param bmDeptPlanArea 两区及乡镇单位部门招商计划
     * @return 两区及乡镇单位部门招商计划
     */
    @Override
    public List<BmDeptPlanArea> selectBmDeptPlanAreaList(BmDeptPlanArea bmDeptPlanArea)
    {
        return bmDeptPlanAreaMapper.selectBmDeptPlanAreaList(bmDeptPlanArea);
    }

    /**
     * 新增两区及乡镇单位部门招商计划
     * 
     * @param bmDeptPlanArea 两区及乡镇单位部门招商计划
     * @return 结果
     */
    @Override
    public int insertBmDeptPlanArea(BmDeptPlanArea bmDeptPlanArea)
    {
        bmDeptPlanArea.setCreateTime(DateUtils.getNowDate());
        return bmDeptPlanAreaMapper.insertBmDeptPlanArea(bmDeptPlanArea);
    }

    /**
     * 修改两区及乡镇单位部门招商计划
     * 
     * @param bmDeptPlanArea 两区及乡镇单位部门招商计划
     * @return 结果
     */
    @Override
    public int updateBmDeptPlanArea(BmDeptPlanArea bmDeptPlanArea)
    {
        bmDeptPlanArea.setUpdateTime(DateUtils.getNowDate());
        return bmDeptPlanAreaMapper.updateBmDeptPlanArea(bmDeptPlanArea);
    }

    /**
     * 批量删除两区及乡镇单位部门招商计划
     * 
     * @param ids 需要删除的两区及乡镇单位部门招商计划ID
     * @return 结果
     */
    @Override
    public int deleteBmDeptPlanAreaByIds(Long[] ids)
    {
        return bmDeptPlanAreaMapper.deleteBmDeptPlanAreaByIds(ids);
    }

    /**
     * 删除两区及乡镇单位部门招商计划信息
     * 
     * @param id 两区及乡镇单位部门招商计划ID
     * @return 结果
     */
    @Override
    public int deleteBmDeptPlanAreaById(Long id)
    {
        return bmDeptPlanAreaMapper.deleteBmDeptPlanAreaById(id);
    }

    /**
     * 首页 -两区及乡镇榜单
     * @return
     */
    @Override
    public List<BmDeptPlanArea> selectAreaList(String year) {
        List<BmDeptPlanArea> BmDeptPlanAreaList = bmDeptPlanAreaMapper.selectAreaList(year);
        return BmDeptPlanAreaList;
    }
}
